#!/usr/bin/env python
################################################################################
# MIT License
#
# Copyright (c) 2020 Hajime Nakagami
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
################################################################################
import sys
from argparse import ArgumentParser
import pyawabi

def main():
    parser = ArgumentParser()
    parser.add_argument('-N', '--nbest', type=int)
    args = parser.parse_args()

    tokenizer = pyawabi.Tokenizer(None)
    for s in sys.stdin.readlines():
        if args.nbest:
            for tokens in tokenizer.tokenize_n_best(s, args.nbest):
                for token in tokens:
                    print("{}\t{}".format(token[0], token[1]))
                print("EOS")
        else:
            for token in tokenizer.tokenize(s):
                print("{}\t{}".format(token[0], token[1]))
            print("EOS")


if __name__ == '__main__':
    main()
